==> huaweicloudsdkdcs-3.1.66-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/show_config_history_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowConfigHistoryDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'history_id': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'history_id': 'history_id'
    }

    def __init__(self, instance_id=None, history_id=None):
        """ShowConfigHistoryDetailRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID
        :type instance_id: str
        :param history_id: 历史实例ID
        :type history_id: str
        """
        
        

        self._instance_id = None
        self._history_id = None
        self.discriminator = None

        self.instance_id = instance_id
        self.history_id = history_id

    @property
    def instance_id(self):
        """Gets the instance_id of this ShowConfigHistoryDetailRequest.

        实例ID

        :return: The instance_id of this ShowConfigHistoryDetailRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ShowConfigHistoryDetailRequest.

        实例ID

        :param instance_id: The instance_id of this ShowConfigHistoryDetailRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def history_id(self):
        """Gets the history_id of this ShowConfigHistoryDetailRequest.

        历史实例ID

        :return: The history_id of this ShowConfigHistoryDetailRequest.
        :rtype: str
        """
        return self._history_id

    @history_id.setter
    def history_id(self, history_id):
        """Sets the history_id of this ShowConfigHistoryDetailRequest.

        历史实例ID

        :param history_id: The history_id of this ShowConfigHistoryDetailRequest.
        :type history_id: str
        """
        self._history_id = history_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowConfigHistoryDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdcs-3.1.157-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/show_config_history_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowConfigHistoryDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'history_id': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'history_id': 'history_id'
    }

    def __init__(self, instance_id=None, history_id=None):
        r"""ShowConfigHistoryDetailRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID
        :type instance_id: str
        :param history_id: 历史实例ID
        :type history_id: str
        """
        
        

        self._instance_id = None
        self._history_id = None
        self.discriminator = None

        self.instance_id = instance_id
        self.history_id = history_id

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ShowConfigHistoryDetailRequest.

        实例ID

        :return: The instance_id of this ShowConfigHistoryDetailRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ShowConfigHistoryDetailRequest.

        实例ID

        :param instance_id: The instance_id of this ShowConfigHistoryDetailRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def history_id(self):
        r"""Gets the history_id of this ShowConfigHistoryDetailRequest.

        历史实例ID

        :return: The history_id of this ShowConfigHistoryDetailRequest.
        :rtype: str
        """
        return self._history_id

    @history_id.setter
    def history_id(self, history_id):
        r"""Sets the history_id of this ShowConfigHistoryDetailRequest.

        历史实例ID

        :param history_id: The history_id of this ShowConfigHistoryDetailRequest.
        :type history_id: str
        """
        self._history_id = history_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowConfigHistoryDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
